gx.cnppltsgx.cnpplts, and change them and the legend font size, if required. Any changes require editing the function and some elementary R-scripting skills, see Note below.gx.cnpplts.setup(display = FALSE)display = TRUE the symbol mark and colour combinations are displayed on the current device. If display = FALSE output is suppressed.gx.cnpplts, the default is 0.8.gx.cnpplts, the default is 0.9.display.marks, points, display.lty